# Build Notes:
# 
# This package requires mimelib, which is part of KDE. It was in
# kdenetwork, but has since been moved to the kdepim package, thus our
# dependency on kdepim.
#
# The configure script will discover the location of mimelib/*.h files
# by iterating over a few common KDE include paths. However even
# though the correct KDE include path is discovered the compile test
# will fail. This is because the chain of includes in the KDE header
# files includes kdelibs_export.h which includes the QT file qglobal.h
# as a convenience. The problem is that on Red Hat systems (perhaps others
# as well) the QT include files are installed elsewhere in a
# non-standard location, thus qglobal.h can't be found even though the
# KDE include path is correct. To fix this problem we locate the QT
# install directory via /etc/profile.d/qt.sh which sets the QTDIR
# environment variable. We then add -I$QTDIR/include by setting the
# CPPFLAGS environment variable before configure runs. configure
# automatically picks up CPPFLAGS from the environment and will then
# append it with the location of the KDE include files.


Summary: Mailing list archiver with web interface, searching, and threading.
Name: lurker
Version: 1.3
Release: 4%{?dist}
License: GPL
Group: Applications/Internet
URL: http://lurker.sourceforge.net/

Source0: %{name}-%{version}.tar.gz
Source1: lurker-httpd.conf.in

Patch0: lurker-install.patch

%define www_owner apache
%define www_group apache
%define mta_owner mail
%define mta_group mail

%define docdir         %{_datadir}/doc/%{name}-%{version}
%define confdir        %{_sysconfdir}/%{name}
%define configfile     %{confdir}/%{name}.conf
%define listconfigfile %{confdir}/lists.conf
%define srcroot        %{_builddir}/%{buildsubdir}
%define wwwdir         %{_localstatedir}/www/%{name}
%define cgidir         %{wwwdir}/cgi-bin
%define dbdir          %{_localstatedir}/lib/%{name}
%define httpdconfdir   %{_sysconfdir}/httpd/conf.d
%define httpdconffile  %{name}.conf

BuildRequires: autoconf gcc-c++ zlib-devel kdepim-devel

Requires: zlib libxslt kdepim

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Lurker is a mailing list archiver with a web interface. It features
fast complex searches, chronological threading, message threading
navigation, mime handling, file attachment support, multi language
suport, web server caching for efficiency, and it has customizable
output via it's use of XML/XSLT.

%prep
%setup -q
%patch0 -p1 -b .install
cp $RPM_SOURCE_DIR/lurker-httpd.conf.in httpd.conf.in
autoreconf

%build
unset QTDIR || : ; . /etc/profile.d/qt.sh
export CPPFLAGS=-I$QTDIR/include
%configure \
--with-wwwdir=%{wwwdir} \
--with-cgidir=%{cgidir} \
--with-configfile=%{configfile}

make

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install

# Install the config file
mkdir -p $RPM_BUILD_ROOT/%{confdir}
install -m644 %{srcroot}/lurker.conf $RPM_BUILD_ROOT%{configfile}
touch $RPM_BUILD_ROOT%{listconfigfile}

# Install (create) the database directory, initially empty
# FIXME: this should only be writeable by lurker, but at the moment
# the lurker indexer can run as an arbitrary user (e.g. via MTA or procmail)
# thus the database is world writable :-( this should be tighted up.
install -d -m777 $RPM_BUILD_ROOT%{dbdir}

# Install the httpd configuration file.
install -m755 -d $RPM_BUILD_ROOT%{httpdconfdir}
install -m644 $RPM_BUILD_DIR/${RPM_PACKAGE_NAME}-${RPM_PACKAGE_VERSION}/httpd.conf $RPM_BUILD_ROOT%{httpdconfdir}/%{httpdconffile}

# Install the documentation files
install -m755 -d $RPM_BUILD_ROOT%{docdir}
for f in FAQ AUTHORS ChangeLog INSTALL NEWS COPYING README
do
	install -m644 %{srcroot}/$f   $RPM_BUILD_ROOT%{docdir}
done


%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root)
%doc %{_mandir}
%doc %{docdir}
%{_bindir}
%attr(0644,root,root) %config(noreplace) %verify(not md5 size mtime) %{configfile}
%attr(0644,root,root) %config(noreplace) %verify(not md5 size mtime) %{listconfigfile}
%config(noreplace) %{httpdconfdir}/%{httpdconffile}
%{dbdir}
%defattr(0755,%{www_owner},%{www_group})
%{wwwdir}

%changelog
* Wed Mar 15 2006 John Dennis <jdennis@redhat.com> - 1.3
- replace aclocal et.al. with autoreconf, clean up some macros

* Wed Feb 15 2006 John Dennis <jdennis@redhat.com> - 1.3-3
- fix httpd conf file

* Mon Feb 13 2006 John Dennis <jdennis@redhat.com> - 1.3-2
- add --with-wwwdir, --with-cgidir, --with-dbdir, --with-configfile to configure
- remove etcdir, vardir, clean up reference to these in lurker.conf.in
- add #defines of CONFIGFILE and DOCROOT to configure, intialize to default
  values in main routine of various executables
- remove hardcoded definition of cgidir in render/Makefile.am
- add installation of http/conf.d/lurker.conf, based on configure parameters
- add lists.conf as empty config file, include from lurker.conf

* Wed Feb  8 2006 John Dennis <jdennis@redhat.com> - 1.3-1
- add install patch, moves lib/cgi-bin to lib/lurker/cgi-bin

* Wed Feb  1 2006 John Dennis <jdennis@redhat.com> - 
- Initial build.

